@@ -13,10 +13,10 @@ test_that("Single gloss lines are printed", {
     as_gloss(a, b, translation = t, source = s, label = l,
              output_format = "latex")
   ))
-  expect_snapshot_output(knit_print(
-    as_gloss(a, b, translation = t, source = s, label = l,
-             output_format = "word")
-  ))
+  # expect_snapshot_output(knit_print(
+  #   as_gloss(a, b, translation = t, source = s, label = l,
+  #            output_format = "word")
+  # ))
 })
 
 test_that("Single gloss lines without source are printed", {
@@ -28,10 +28,10 @@ test_that("Single gloss lines without source are printed", {
     as_gloss(a, b, translation = t, label = l,
              output_format = "latex")
   ))
-  expect_snapshot_output(knit_print(
-    as_gloss(a, b, translation = t, label = l,
-             output_format = "word")
-  ))
+  # expect_snapshot_output(knit_print(
+  #   as_gloss(a, b, translation = t, label = l,
+  #            output_format = "word")
+  # ))
 })
 
 
@@ -45,7 +45,7 @@ test_that("Series of gloss lines are printed", {
   expect_snapshot_output(knit_print(
     gloss_list(gloss_df(glosses, output_format = "latex")))
   )
-  expect_snapshot_output(knit_print(
-    gloss_df(glosses, output_format = "word"))
-  )
+  # expect_snapshot_output(knit_print(
+  #   gloss_df(glosses, output_format = "word"))
+  # )
 })
