@@ -5,7 +5,7 @@ test_that("long string formating works", {
 })
 
 # test gloss_list ----
-
+glosses <- dplyr::select(glosses, -language)
 test_that("gloss_list has the right class", {
   expect_error(gloss_list("not a gloss"))
   gl <- gloss_list(gloss_df(glosses))
@@ -24,7 +24,10 @@ test_that("gloss_list renders properly with latex", {
   options("glossr.output" = "latex")
   from_glosses <- gloss_df(glosses)
   gl <- gloss_list(from_glosses)
-  expect_match(gl[[1]], "^\\\\pex \\n$")
-  expect_match(gl[[2]], "^\\\\a$")
-  expect_identical(gl[[3]], gloss_df(glosses)[[2]])
+  for (gloss_item in from_glosses) {
+    as_re <- gsub("\\\\ex", "\\\\a", gloss_item) %>%
+      gsub(pattern = "\\\\xe \\n", replacement = "") %>%
+      gsub(pattern = "([\\{\\(])", replacement = "\\\\\\1")
+    expect_match(gl[[1]], as_re)
+  }
 })
